<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>About</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <location filename="../about.ui" line="47"/>
        <source>Packet Sender</source>
        <translation>Packet Sender</translation>
    </message>
    <message>
        <location filename="../about.ui" line="136"/>
        <source>Written by Dan Nagle and published by NagleCode, LLC</source>
        <translation>Escrito por Dan Nagle y publicado por NagleCode, LLC</translation>
    </message>
    <message>
        <location filename="../about.ui" line="165"/>
        <source>TextLabel</source>
        <translation>Etiqueta de Texto</translation>
    </message>
    <message>
        <location filename="../about.ui" line="185"/>
        <source>PacketSender.com</source>
        <translation>PacketSender.com</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="26"/>
        <source>
Commit Hash: </source>
        <translation>
Hash de confirmación: </translation>
    </message>
    <message>
        <location filename="../about.cpp" line="31"/>
        <source>About Packet Sender</source>
        <translation>Acerca de Packet Sender</translation>
    </message>
</context>
<context>
    <name>BruceThePoodle</name>
    <message>
        <location filename="../brucethepoodle.ui" line="26"/>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <location filename="../brucethepoodle.cpp" line="29"/>
        <source>Bruce The Poodle!</source>
        <translation>¡Bruce el Caniche!</translation>
    </message>
</context>
<context>
    <name>CloudUI</name>
    <message>
        <location filename="../cloudui.ui" line="14"/>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="28"/>
        <source>Account</source>
        <translation>Cuenta</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="49"/>
        <source>Packet Sender Cloud</source>
        <translation>Packet Sender en la Nube</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="73"/>
        <source>Username</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="91"/>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="112"/>
        <source>Confirm Password</source>
        <translation>Confirmar contraseña</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="131"/>
        <source>Remember Login</source>
        <translation>Recordar Sesión</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="140"/>
        <location filename="../cloudui.cpp" line="466"/>
        <source>Login</source>
        <translation>Ingresar</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="150"/>
        <location filename="../cloudui.cpp" line="465"/>
        <source>Create a new account.</source>
        <translation>Crear una cuenta nueva.</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="187"/>
        <source>Privacy</source>
        <translation>Privacidad</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="194"/>
        <source>Terms</source>
        <translation>Términos</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="214"/>
        <source>cloud.packetsender.com/help</source>
        <translation>cloud.packetsender.com/help</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="228"/>
        <source>Import</source>
        <translation>importar</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="239"/>
        <source>Import From URL</source>
        <translation>Importar desde una URL</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="248"/>
        <location filename="../cloudui.ui" line="372"/>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="268"/>
        <source>View URL</source>
        <translation>Ver URL</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="283"/>
        <source>Delete Packet Set</source>
        <translation>Eliminar Conjunto de Paquetes</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="290"/>
        <source>Import Packet Set</source>
        <translation>Importar Conjunto de Paquetes</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="307"/>
        <source>Save / Share</source>
        <translation>Guardar / Compartir</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="313"/>
        <source>You are sharing.</source>
        <translation>Estás compartiendo.</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="322"/>
        <source>Packet Set Name</source>
        <translation>Nombre del Conjunto de Paquetes</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="336"/>
        <source>Public Path</source>
        <translation>Ruta Pública</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="359"/>
        <source>Make Public</source>
        <translation>Hacer Público</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="401"/>
        <source>Save to Packet Sender Cloud</source>
        <translation>Guardar en la Nube de Packet Sender</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="83"/>
        <source>Cloud</source>
        <translation>La Nube</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="100"/>
        <source>Saving </source>
        <translation>Guardando</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="100"/>
        <source> packet set to cloud</source>
        <translation>paquete establecido en la Nube</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="470"/>
        <source>Login instead.</source>
        <translation>Iniciar sesión</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="471"/>
        <source>Sign-up</source>
        <translation>Registrarse</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="528"/>
        <source>Delete Set</source>
        <translation>Eliminar Set</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="533"/>
        <source>Delete the set </source>
        <translation>Eliminar el set </translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="533"/>
        <source> from cloud?</source>
        <translation>¿Desde la Nube?</translation>
    </message>
</context>
<context>
    <name>IrisAndMarigold</name>
    <message>
        <location filename="../irisandmarigold.ui" line="26"/>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
</context>
<context>
    <name>LanguageChooser</name>
    <message>
        <location filename="../languagechooser.ui" line="14"/>
        <source>Choose Language</source>
        <translation>Elige lengua</translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="46"/>
        <source>Español</source>
        <translation>Español</translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="79"/>
        <source>English</source>
        <translation>English</translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="115"/>
        <source>Deutsch</source>
        <translation>Deutsch</translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="151"/>
        <source>Français</source>
        <translation>Français</translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="187"/>
        <source>Italiano</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="206"/>
        <source>OK / Aceptar</source>
        <translation>OK / Aceptar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Ventana Principal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="35"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="48"/>
        <source>Packet Name</source>
        <translation>Nombre del Paquete</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>Request</source>
        <translation>Solicitud</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <source>URL path</source>
        <translation>ruta de la URL</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <source>ASCII</source>
        <translation>ASCII</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="100"/>
        <source>Generate Data</source>
        <translation>Generar Datos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="107"/>
        <source>ASCII representation</source>
        <translation>Representación ASCII</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>Load File</source>
        <translation>Cargar Archivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="128"/>
        <source>HEX</source>
        <translation>HEX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="135"/>
        <source>HEX representation</source>
        <translation>Representación HEX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="151"/>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>IPv4, IPv6, DNS Lookup</source>
        <translation>Buscar IPv4, IPv6, DNS</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Port</source>
        <translation>Puerto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="184"/>
        <source>1 to 65535</source>
        <translation>1 a 65535</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>Resend Delay</source>
        <translation>Retraso de Reenvío</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="207"/>
        <source>0.0/blank off</source>
        <translation>0.0/desactivar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>TCP</source>
        <translation>TCP</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="239"/>
        <source>UDP</source>
        <translation>UDP</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>SSL</source>
        <translation>SSL</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="257"/>
        <source>HTTP Get</source>
        <translation>HTTP Get</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="266"/>
        <source>HTTP Post</source>
        <translation>HTTP Post</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="275"/>
        <source>HTTPS Get</source>
        <translation>HTTPS Get</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="284"/>
        <source>HTTPS Post</source>
        <translation>HTTPS Post</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <location filename="../mainwindow.cpp" line="1073"/>
        <location filename="../mainwindow.cpp" line="1731"/>
        <source>Send</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="303"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Search Saved Packets...</source>
        <translation>Buscando Paquetes Guardados...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="361"/>
        <source>Generate Panel!</source>
        <translation>¡Generar Panel!</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="384"/>
        <source>Delete Saved Packet</source>
        <translation>Eliminar Paquete Guardado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="391"/>
        <source>Persistent TCP</source>
        <translation>TCP Persistente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>Clear Log</source>
        <translation>Borrar Registro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="448"/>
        <source>Log Traffic</source>
        <translation>Registrar Tráfico</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="458"/>
        <source>Save Log</source>
        <translation>Guardar Registro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="465"/>
        <source>Save Traffic Packet</source>
        <translation>Guardar Paquete de Tráfico</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="472"/>
        <source>Copy to Clipboard</source>
        <translation>Copiar al Portapapeles</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="520"/>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="529"/>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="540"/>
        <source>&amp;Tools</source>
        <translation>&amp;Herramientas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="550"/>
        <source>&amp;Multicast</source>
        <translation>&amp;Multidifusión</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="556"/>
        <source>Panels</source>
        <translation>Páneles</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="574"/>
        <source>E&amp;xit</source>
        <translation>&amp;Salida</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="583"/>
        <source>&amp;Settings</source>
        <translation>&amp;Ajustes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="592"/>
        <source>&amp;About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="601"/>
        <source>&amp;Import Database</source>
        <translation>Importar Base de Datos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="610"/>
        <source>&amp;Export Database</source>
        <translation>Exportar Base de Datos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="615"/>
        <source>Persistent Connection</source>
        <translation>Conexión Persistente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="624"/>
        <source>&amp;Subnet Calculator</source>
        <translation>Calculadora de Subred</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="633"/>
        <source>D&amp;onate (Thank You!)</source>
        <translation>Donar (¡Gracias!)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="638"/>
        <source>Documentation</source>
        <translation>Documentación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="647"/>
        <source>&amp;Documentation</source>
        <translation>&amp;Documentación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="652"/>
        <source>Export To Cloud</source>
        <translation>Exportar a la Nube</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="661"/>
        <source>&amp;Cloud Save and Share</source>
        <translation>Guardar y Compartir en la Nube</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="670"/>
        <source>&amp;Join/Leave IPv4</source>
        <translation>Unirse/Abandonar IPv4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="679"/>
        <source>Android App</source>
        <translation>Aplicación de Android</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="688"/>
        <source>iOS App</source>
        <translation>Aplicación de iOS</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="697"/>
        <source>Follow on Twitter</source>
        <translation>Seguir en Twitter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="706"/>
        <source>Connect on LinkedIn</source>
        <translation>Conectar en LinkedIn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="715"/>
        <source>Intense &amp;Traffic Generator</source>
        <translation>Generador de Tráfico Intenso</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="724"/>
        <source>Forums</source>
        <translation>Foros</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="729"/>
        <source>Load Starter Panel</source>
        <translation>Cargar Panel Inicial</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="734"/>
        <source>Empty Panel Project</source>
        <translation>Vaciar Panel del Proyecto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="593"/>
        <location filename="../mainwindow.cpp" line="621"/>
        <source>Updates.</source>
        <translation>Actualizaciones.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="597"/>
        <source>There is a new Packet Sender available.

Download?</source>
        <translation>Hay un nuevo Packet Sender disponible.

¿Descargar?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="625"/>
        <source>Let Packet Sender check for updates weekly?</source>
        <translation>¿Permitir que Packet Sender busque actualizaciones semanalmente?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="669"/>
        <source>Packet Sender Updated!</source>
        <translation>¡Packet Sender actualizado!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="673"/>
        <source>Updated to </source>
        <translation>Actualizado a </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="673"/>
        <source>!

Would you like to read the release notes?</source>
        <translation>!

¿Le gustaría leer las notas de la versión?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="734"/>
        <source>Clear Log </source>
        <translation>Borrar registro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="759"/>
        <location filename="../mainwindow.cpp" line="781"/>
        <location filename="../mainwindow.cpp" line="802"/>
        <source> Ports</source>
        <translation>Puertos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="765"/>
        <source>UDP Server Disabled</source>
        <translation>Servidor UDP Deshabilitado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="787"/>
        <source>SSL Server Disabled</source>
        <translation>Servidor SSL Deshabilitado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="809"/>
        <source>TCP Server Disabled</source>
        <translation>Servidor TCP Deshabilitado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1029"/>
        <location filename="../mainwindow.cpp" line="1270"/>
        <source>Multicast detected.</source>
        <translation>Difusión Múltiple detectada</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1033"/>
        <source>Do you wish to join the multicast group?</source>
        <translation>¿Desea unirse al grupo de Difusión Múltiple?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1049"/>
        <location filename="../mainwindow.cpp" line="1292"/>
        <source>Broadcast with responses!</source>
        <translation>¡Transmitir con Respuesta!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1053"/>
        <location filename="../mainwindow.cpp" line="1296"/>
        <source>You are sending a broadcast packet with responses enabled.

This could cause traffic flooding. Continue?</source>
        <translation>Está enviando un paquete de difusión con respuestas habilitadas.

Esto puede causar una inundación de tráfico. ¿Continuar?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="233"/>
        <location filename="../mainwindow.cpp" line="1067"/>
        <location filename="../mainwindow.cpp" line="1332"/>
        <location filename="../mainwindow.cpp" line="1938"/>
        <source>Resending</source>
        <translation>Reenviando</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1073"/>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1100"/>
        <source>Name cannot be blank.</source>
        <translation>El nombre no puede ser vacío</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1104"/>
        <source>Name is empty.</source>
        <translation>El nombre está vacío</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1154"/>
        <source>This computer does not support SSL.

Expected SSL:</source>
        <translation>Esta computadora no soporta SSL.

SSL Esperado:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1158"/>
        <source>No SSL Library.</source>
        <translation>Sin Librerías SSL</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1211"/>
        <source>Address cannot be blank.</source>
        <translation>La Dirección no puede estar vacía</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1215"/>
        <source>Address is empty.</source>
        <translation>La dirección está vacía</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1226"/>
        <source>Port cannot be blank/zero.</source>
        <translation>El puerto no puede estar vacío o ser cero</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1230"/>
        <source>Port is zero.</source>
        <translation>El puerto es cero</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1244"/>
        <source>IPv6?</source>
        <translation>¿IPv6?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1248"/>
        <source>Enable IPv6 support?</source>
        <translation>¿Habilitar Puerto IPv6?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1274"/>
        <source>Join UDP multicast group?</source>
        <translation>¿Unirse al Grupo de Difusión Múltiple UDP?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1312"/>
        <source>Resend TCP with persistent connections!</source>
        <translation>¡Reenviar TCP con conexiones persistentes!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1316"/>
        <source>You are resending a TCP packet with persistent connections. The UI could spawn numerous windows! 

Uncheck persistent connection? (Recommended)</source>
        <translation>Se trata de reenviar un paquete TCP con conexiones persistentes. La interfaz podría generar numerosas ventanas.

¿Desmarcar la conexión persistente? (Recomendado)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1351"/>
        <location filename="../mainwindow.cpp" line="2001"/>
        <source>No packets selected.</source>
        <translation>No hay paquetes seleccionados</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1355"/>
        <source>Select a packet.</source>
        <translation>Seleccionar un paquete.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1394"/>
        <source>Invalid Address / DNS failed</source>
        <translation>Dirección Inválida / Error de DNS</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1417"/>
        <source>Invalid Port</source>
        <translation>Puerto Inválido</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1861"/>
        <source>Clear Log (0)</source>
        <translation>Limpiar Registro (0)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1880"/>
        <source>Save Packet</source>
        <translation>Guardar Paquete</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1881"/>
        <source>Packet name:</source>
        <translation>Nombre del Paquete:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2005"/>
        <source>Clipboard unchanged.</source>
        <translation>Portapapeles sin cambios</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2066"/>
        <source>Save Traffic Log</source>
        <translation>Guardar Registro de Tráfico</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2067"/>
        <source>log (*.log)</source>
        <translation>Registro (*.log)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2085"/>
        <source>TIME</source>
        <translation>TIEMPO</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2085"/>
        <source>From IP</source>
        <translation>IP Inicial</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2085"/>
        <source>From Port</source>
        <translation>Puerto Inicial</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2085"/>
        <source>To IP</source>
        <translation>IP Final</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2086"/>
        <source>To Port</source>
        <translation>Puerto Final</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2086"/>
        <source>Method</source>
        <translation>Método</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2086"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2261"/>
        <source>Import JSON</source>
        <translation>importar JSON</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2263"/>
        <location filename="../mainwindow.cpp" line="2330"/>
        <source>JSON db (*.json)</source>
        <translation>db JSON (*.json)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2287"/>
        <location filename="../mainwindow.cpp" line="2424"/>
        <source>Found </source>
        <translation>Encontrado </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2287"/>
        <location filename="../mainwindow.cpp" line="2424"/>
        <source> packets!</source>
        <translation> paquetes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2291"/>
        <location filename="../mainwindow.cpp" line="2428"/>
        <source>Import </source>
        <translation>Importar </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2291"/>
        <location filename="../mainwindow.cpp" line="2428"/>
        <source> packets?

Packet Sender will overwrite packets with the same name.</source>
        <translation> paquetes?

Packet Sender sobrescribirá los paquetes con el mismo nombre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2294"/>
        <location filename="../mainwindow.cpp" line="2315"/>
        <location filename="../mainwindow.cpp" line="2431"/>
        <location filename="../mainwindow.cpp" line="2452"/>
        <source>Import Cancelled</source>
        <translation>Importación Cancelada</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2302"/>
        <source>Import Finished</source>
        <translation>Importación Finalizada</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2308"/>
        <location filename="../mainwindow.cpp" line="2445"/>
        <source>Not a database</source>
        <translation>No es una base de datos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2312"/>
        <location filename="../mainwindow.cpp" line="2449"/>
        <source>Found no packets in this file. It may not be a Packet Sender export</source>
        <translation>No se encontraron paquetes en este archivo. Puede que no sea una exportación de Packet Sender</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2329"/>
        <source>Save JSON</source>
        <translation>Guardar JSON</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2351"/>
        <location filename="../mainwindow.cpp" line="2484"/>
        <source>Export: </source>
        <translation>Exportar: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2355"/>
        <source>Could not save</source>
        <translation>No se pudo guardar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2359"/>
        <source>Could not open </source>
        <translation>No se pudo abrir </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2405"/>
        <location filename="../mainwindow.cpp" line="2530"/>
        <source>Import File</source>
        <translation>Importar Archivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2407"/>
        <location filename="../mainwindow.cpp" line="2462"/>
        <source>INI db (*.ini)</source>
        <translation>db INI (*.ini)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2461"/>
        <source>Save File</source>
        <translation>Guardar Archivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2532"/>
        <source>*.*</source>
        <translation>*.*</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2556"/>
        <source>Max size exceeded!</source>
        <translation>¡Tamaño máximo excedido!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2560"/>
        <source>The HEX field supports up to 10,922 bytes. The data has been truncated.</source>
        <translation>El campo HEX admite hasta 10.922 bytes. Los datos han sido truncados.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2566"/>
        <source>Loading </source>
        <translation>Cargando </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2566"/>
        <source> bytes</source>
        <translation> bytes</translation>
    </message>
</context>
<context>
    <name>MulticastSetup</name>
    <message>
        <location filename="../multicastsetup.ui" line="14"/>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <location filename="../multicastsetup.ui" line="22"/>
        <source>IP Multicast Address</source>
        <translation>Dirección de Multidifusión IP</translation>
    </message>
    <message>
        <location filename="../multicastsetup.ui" line="29"/>
        <source>Join</source>
        <translation>Entrar</translation>
    </message>
    <message>
        <location filename="../multicastsetup.ui" line="54"/>
        <source>Leave All Groups</source>
        <translation>Salir de Todos los Grupos</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="15"/>
        <source>IPv4 Multicast Setup (Experimental)</source>
        <translation>Configuración de Difusión Múltiple IPv4 (Experimental)</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="31"/>
        <source>There are no bound UDP ports</source>
        <translation>No hay Puertos UDP vinculados</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="34"/>
        <source>UDP socket bound to </source>
        <translation>Socket UDP vinculado a </translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="36"/>
        <source> will join the multicast group</source>
        <translation> se unirá al grupo de Difusión Múltiple</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="59"/>
        <source>Not Multicast.</source>
        <translation>Sin Difusión Múltiple</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="63"/>
        <source>IP must be an IPv4 multicast address.
(224.0.0.0 to 239.255.255.255)</source>
        <translation>IP debe ser una dirección IPv4 de difusión múltiple.
(224.0.0.0 a 239.255.255.255)</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="74"/>
        <source>IPv4-only.</source>
        <translation>Sólo IPv4</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="78"/>
        <source>Packet Sender supports multicast when binded to IPv4. 
Turn off IPv6 and switch to IPv4 mode?</source>
        <translation>Packet Sender admite difusión múltiple cuando está vinculado a IPv4.
¿Desactivar IPv6 y cambiar al modo IPv4?</translation>
    </message>
</context>
<context>
    <name>PacketLogModel</name>
    <message>
        <location filename="../packetlogmodel.cpp" line="83"/>
        <source>Data portion is </source>
        <translation>La proporción de datos es </translation>
    </message>
    <message>
        <location filename="../packetlogmodel.cpp" line="83"/>
        <source> bytes</source>
        <translation> bytes</translation>
    </message>
</context>
<context>
    <name>PacketNetwork</name>
    <message>
        <location filename="../packetnetwork.cpp" line="246"/>
        <source>Port bind error.</source>
        <translation>Error al vincular el puerto</translation>
    </message>
    <message>
        <location filename="../packetnetwork.cpp" line="250"/>
        <source>Packet Sender attempted (and failed) to bind to port [PORT], which is less than 1024. 

Privileged ports requires running Packet Sender with admin-level / root permissions.</source>
        <translation>Packet Sender intentó (y falló) vincularse al puerto [PORT], que es inferior a 1024.

Los puertos privilegiados requieren ejecutar Packet Sender con permisos de nivel de administrador/root.</translation>
    </message>
    <message>
        <location filename="../packetnetwork.cpp" line="251"/>
        <source>Packet Sender attempted (and failed) to bind to port [PORT].

 - Are you running multiple instances? 

 - Trying to bind to a missing custom IP?</source>
        <translation>Packet Sender intentó (y falló) vincularse al puerto [PORT].

- ¿Está ejecutando varias instancias?

- ¿Intenta vincularse a una IP personalizada que no está disponible?</translation>
    </message>
</context>
<context>
    <name>PanelGenerator</name>
    <message>
        <location filename="../panelgenerator.ui" line="20"/>
        <source>MainWindow</source>
        <translation>Ventana principal</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="56"/>
        <location filename="../panelgenerator.ui" line="69"/>
        <location filename="../panelgenerator.ui" line="82"/>
        <location filename="../panelgenerator.ui" line="95"/>
        <location filename="../panelgenerator.ui" line="108"/>
        <location filename="../panelgenerator.ui" line="121"/>
        <location filename="../panelgenerator.ui" line="134"/>
        <location filename="../panelgenerator.ui" line="147"/>
        <location filename="../panelgenerator.ui" line="160"/>
        <source>PushButton</source>
        <translation>Presionar el Botón</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="183"/>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="192"/>
        <source>&amp;Export</source>
        <translation>&amp;Exportar</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="203"/>
        <source>&amp;Help</source>
        <translation>&amp;Ayudar</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="209"/>
        <source>S&amp;ettings</source>
        <translation>&amp;Ajustes</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="223"/>
        <source>&amp;Save</source>
        <translation>&amp;Guardar</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="226"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="231"/>
        <source>Save &amp;As...</source>
        <translation>&amp;Guardarar como</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="236"/>
        <source>&amp;Import Panels File</source>
        <translation>&amp;Importar Archivo de Paneles</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="239"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="244"/>
        <source>Portable &amp;Windows Package</source>
        <translation>Paquete Portátil de Windows</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="247"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="252"/>
        <source>&amp;Documentation</source>
        <translation>&amp;Documentación</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="255"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="260"/>
        <source>Panel Name</source>
        <translation>Nombre del Panel</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="265"/>
        <source>Panel ID</source>
        <translation>Identificación del Panel</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="273"/>
        <source>Starter Panel:</source>
        <translation>Panel Inicial:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="278"/>
        <location filename="../panelgenerator.cpp" line="48"/>
        <source>Delete Panel</source>
        <translation>Eliminar Panel</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="283"/>
        <source>&amp;Panels File</source>
        <translation>Archivo de Paneles</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="288"/>
        <source>Portable &amp;macOS Package</source>
        <translation>Paquete de macOS Portátil</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="293"/>
        <source>Portable Linux Package</source>
        <translation>Paquete de Linux Portátil</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="298"/>
        <source>&amp;New Panel</source>
        <translation>Panel Nuevo</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="301"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="40"/>
        <source>Panels</source>
        <translation>Páneles</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="47"/>
        <source>Load Panel</source>
        <translation>Cargar Panel</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="52"/>
        <location filename="../panelgenerator.cpp" line="364"/>
        <source>Viewing</source>
        <translation>Viendo</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="135"/>
        <source>URL or File</source>
        <translation>URL o Archivo</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="136"/>
        <source>URL or File:</source>
        <translation>URL o Archivo:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="155"/>
        <source>Link text</source>
        <translation>Texto del Enlace</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="156"/>
        <source>Link text:</source>
        <translation>Texto del Enlace:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="321"/>
        <source>Confirm delete.</source>
        <translation>Confirmar Eliminación</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="325"/>
        <source>Delete </source>
        <translation>Eliminar </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="331"/>
        <source>Deleting </source>
        <translation>Eliminando </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="339"/>
        <source>Panel </source>
        <translation>Panel </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="341"/>
        <source>Set Panel Name: </source>
        <translation>Establecer el Nombre del Panel: </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="342"/>
        <source>Set Panel ID: </source>
        <translation>Establecer ID del Panel: </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="346"/>
        <source>Packet Sender Panel: New Panel</source>
        <translation>Panel de Packet Sender: Panel Nuevo</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="347"/>
        <source>Set Panel Name: New Panel</source>
        <translation>Establecer Nombre del Panel: Panel Nuevo</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="348"/>
        <source>Set Panel ID: New Panel</source>
        <translation>Establecer ID del Panel: Panel Nuevo</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="354"/>
        <source>Starter Panel: Yes</source>
        <translation>Panel Inicial: Si</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="356"/>
        <source>Starter Panel: No</source>
        <translation>Panel Inicial: No</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="359"/>
        <source>Editing</source>
        <translation>Editando</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="436"/>
        <source>Button </source>
        <translation>Botón </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="443"/>
        <source>(Button will be deleted)</source>
        <translation>(El botón se eliminará)</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="453"/>
        <source>Test</source>
        <translation>Prueba</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="460"/>
        <source>Script is empty</source>
        <translation>El script está vacío</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="522"/>
        <location filename="../panelgenerator.cpp" line="527"/>
        <source>New Button</source>
        <translation>Botón Nuevo</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="692"/>
        <source>Nothing to do...</source>
        <translation>Nada que hacer...</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="694"/>
        <source>Executing </source>
        <translation>Ejecutando </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="699"/>
        <source>Unknown Command</source>
        <translation>Comando desconocido</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="769"/>
        <source>Transition Panel</source>
        <translation>Panel de Transición</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="773"/>
        <source>Tranisition to Panel &quot;</source>
        <translation>Transición al Panel &quot;</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="773"/>
        <source>&quot;?
This panel has not been saved. You may lose changes.</source>
        <translation>&quot;?
Este panel no se ha guardado. Es posible que se pierdan los cambios.</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="785"/>
        <source>Not loading panel</source>
        <translation>No cargando el panel</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="789"/>
        <source>Not loading panel in edit mode</source>
        <translation>No cargando el panel en el modo de edición</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="905"/>
        <source>Change URL</source>
        <translation>Cambiar URL</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="906"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="913"/>
        <source>Delete link</source>
        <translation>Eliminar Enlace</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="917"/>
        <source>Delete URL link?
</source>
        <translation>¿Eliminar Enlace URL?
</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="928"/>
        <source>Change Text</source>
        <translation>Cambiar Texto</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="929"/>
        <source>text:</source>
        <translation>texto:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="990"/>
        <source>Panels File</source>
        <translation>Archivo de Paneles</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="992"/>
        <source>*.panels</source>
        <translation>*.panels</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1029"/>
        <source>Unknown File</source>
        <translation>Archivo Desconocido</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1032"/>
        <source>This does not seem to be a valid PS Panels file</source>
        <translation>No parece ser un archivo de Páneles de PS válido</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1046"/>
        <location filename="../panelgenerator.cpp" line="1071"/>
        <source>Found </source>
        <translation>Encontrado </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1046"/>
        <source> packets. Saving overwrites duplicate names.

Continue packet import?</source>
        <translation> paquetes. Guardar sobrescribirá los nombres duplicados.

¿Continuar la exportación de paquetes?</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1071"/>
        <source> panels. Ovewrite dpulicated IDs?

Selecting No will generate new IDs and append.</source>
        <translation> páneles. ¿Sobrescribir los ID duplicados?

        Seleccionar No generará nuevos ID y los Adjuntará.</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1143"/>
        <source>Coming soon.</source>
        <translation>Pronto.</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1160"/>
        <source>Change Name</source>
        <translation>Cambiar Nombre</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1161"/>
        <location filename="../panelgenerator.cpp" line="1209"/>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1177"/>
        <source>Change ID</source>
        <translation>Cambiar Identificación</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1178"/>
        <source>ID:</source>
        <translation>Identificación:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1208"/>
        <source>New Name</source>
        <translation>Nombre Nuevo</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1243"/>
        <source>Save PS Panels</source>
        <translation>Guardar Paneles PS</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1244"/>
        <source>panels (*.panels)</source>
        <translation>Páneles (*.panels)</translation>
    </message>
</context>
<context>
    <name>PersistentConnection</name>
    <message>
        <location filename="../persistentconnection.ui" line="14"/>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="26"/>
        <source>Waiting...</source>
        <translation>Esperando...</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="40"/>
        <source>Load</source>
        <translation>Carga</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="47"/>
        <source>Search Packets...</source>
        <translation>Buscando Paquetes...</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="61"/>
        <source>Raw</source>
        <translation>Raw</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="71"/>
        <source>ASCII</source>
        <translation>ASCII</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="84"/>
        <source>ASCII. Press Enter to Send.</source>
        <translation>ASCII. Presione Entrar para enviar.</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="94"/>
        <source>Send</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="104"/>
        <source>Append \r</source>
        <translation>Adjuntar \r</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="114"/>
        <location filename="../persistentconnection.cpp" line="468"/>
        <source>Send File</source>
        <translation>Enviar Archivo</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="158"/>
        <source>Clear Log</source>
        <translation>Borrar Registro</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="165"/>
        <source>To Clipboard</source>
        <translation>Al Portapapeles</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="185"/>
        <source>Resending(1)</source>
        <translation>Reenviando(1)</translation>
    </message>
    <message>
        <location filename="../persistentconnection.cpp" line="154"/>
        <location filename="../persistentconnection.cpp" line="156"/>
        <source>You:</source>
        <translation>Usted:</translation>
    </message>
    <message>
        <location filename="../persistentconnection.cpp" line="470"/>
        <source>*.*</source>
        <translation>*.*</translation>
    </message>
    <message>
        <location filename="../persistentconnection.cpp" line="511"/>
        <source>Copied</source>
        <translation>Copiado</translation>
    </message>
    <message>
        <location filename="../persistentconnection.cpp" line="512"/>
        <source>Output sent to your clipboard</source>
        <translation>Salida enviada al portapapeles</translation>
    </message>
</context>
<context>
    <name>PersistentHTTP</name>
    <message>
        <location filename="../persistenthttp.ui" line="26"/>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <location filename="../persistenthttp.ui" line="44"/>
        <source>Copy Code</source>
        <translation>Copiar Código</translation>
    </message>
    <message>
        <location filename="../persistenthttp.ui" line="64"/>
        <source>.html View/Edit</source>
        <translation>Ver/Editar</translation>
    </message>
</context>
<context>
    <name>PostDataGen</name>
    <message>
        <location filename="../postdatagen.ui" line="14"/>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <location filename="../postdatagen.ui" line="22"/>
        <source>Key</source>
        <translation>Clave</translation>
    </message>
    <message>
        <location filename="../postdatagen.ui" line="32"/>
        <source>Value</source>
        <translation>Valor</translation>
    </message>
    <message>
        <location filename="../postdatagen.ui" line="42"/>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <location filename="../postdatagen.ui" line="51"/>
        <source>Params</source>
        <translation>Parámetros</translation>
    </message>
    <message>
        <location filename="../postdatagen.cpp" line="30"/>
        <source>Data Generator</source>
        <translation>Generador de Fechas</translation>
    </message>
</context>
<context>
    <name>PreviewFilter</name>
    <message>
        <location filename="../mainwindow.cpp" line="2725"/>
        <source>Multi-line editor</source>
        <translation>Editor Multi Líneas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2731"/>
        <source>Update</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2732"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../packet.cpp" line="266"/>
        <location filename="../settings.cpp" line="44"/>
        <source>Send</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <location filename="../packet.cpp" line="267"/>
        <source>Send &lt;b&gt;</source>
        <translation>Enviar &lt;b&gt;</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="47"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="50"/>
        <source>Resend</source>
        <translation>Reenviar</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="53"/>
        <source>To Address</source>
        <translation>Para Final</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="56"/>
        <source>To Port</source>
        <translation>Puerto Final</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="59"/>
        <source>Method</source>
        <translation>Método</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="62"/>
        <source>Request Path</source>
        <translation>Solicitud de Ruta</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="65"/>
        <source>Time</source>
        <translation>Tiempo</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="68"/>
        <source>From IP</source>
        <translation>IP Inicial</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="71"/>
        <source>From Port</source>
        <translation>Puerto Inicial</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="74"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="24"/>
        <source>Network</source>
        <translation>Red</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="30"/>
        <source>Basic</source>
        <translation>Básico</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="36"/>
        <source>Enable UDP Servers</source>
        <translation>Habilitar Servidores UDP</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="45"/>
        <source>UDP Server Ports (comma-separated, 0 for random)</source>
        <translation>Puertos de Servidor UDP (separados por comas, 0 para aleatorio)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="52"/>
        <location filename="../settings.ui" line="77"/>
        <location filename="../settings.ui" line="102"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="61"/>
        <source>Enable TCP Servers</source>
        <translation>Habilitar Servidores TCP</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="70"/>
        <source>TCP Server Port (comma-separated, 0 for random)</source>
        <translation>Puerto del Servidor TCP (separados por comas, 0 para aleatorio)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="86"/>
        <source>Enable SSL/TLS Servers</source>
        <translation>Habilitar Servidores SSL/TLS</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="95"/>
        <source>SSL Server Port (comma-separated, 0 for random)</source>
        <translation>Puerto del Servidor SSL (separados por comas, 0 para aleatorio)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="111"/>
        <source>Set the server ports to 0 if you want to run multiple Packet Sender instances.</source>
        <translation>Establezca los puertos del servidor en 0 si desea ejecutar varias instancias de Packet Sender.</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="125"/>
        <source>Translate macros when sending</source>
        <translation>Traducir macros al enviar</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="132"/>
        <source>Send a basic response with macro support</source>
        <translation>Enviar una respuesta básica con soporte de macros</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="141"/>
        <source>Response Data</source>
        <translation>Datos de Respuesta</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="155"/>
        <source>ASCII</source>
        <translation>ASCII</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="169"/>
        <location filename="../settings.ui" line="771"/>
        <location filename="../settings.ui" line="833"/>
        <location filename="../settings.ui" line="867"/>
        <location filename="../settings.ui" line="908"/>
        <location filename="../settings.ui" line="941"/>
        <source>HEX</source>
        <translation>HEX</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="197"/>
        <source>Additional UDP/TCP/SSL Settings</source>
        <translation>Configuración Adicional de UDP/TCP/SSL</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="205"/>
        <source>IPv4 Only</source>
        <translation>Solo IPv4</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="218"/>
        <source>IPv6 Only</source>
        <translation>Solo IPv6</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="230"/>
        <source>Bind This:</source>
        <translation>Vincular Esto:</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="240"/>
        <source>Your IP</source>
        <translation>Su dirección IP</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="253"/>
        <source>Multi-Send Delay (sec)</source>
        <translation>Retraso de Envío múltiple (seg)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="260"/>
        <source>0.0 for off</source>
        <translation>0.0 para apagado</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="271"/>
        <source>Cancel Resending after # packets</source>
        <translation>Cancelar Reenvío después de # paquetes</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="278"/>
        <source>0 for off</source>
        <translation>0 para apagado</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="287"/>
        <source>Attempt Receive Before Send</source>
        <translation>Intentar recibir antes de enviar</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="294"/>
        <source>500 ms delay after connect (slow devices)</source>
        <translation>Retraso de 500 ms después de la conexión (dispositivos lentos)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="301"/>
        <source>Persistent TCP Connections</source>
        <translation>Conexiones TCP Persistentes</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="308"/>
        <source>Resolve DNS during input (old method)</source>
        <translation>Resolver DNS durante la entrada (método antiguo)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="315"/>
        <source>Ignore SSL Errors (Wrong host, expired, self-signed, etc)</source>
        <translation>Ignorar errores de SSL (host incorrecto, caducado, autofirmado, etc.)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="328"/>
        <source>SSL Server may use an internal snake oil cert</source>
        <translation>El servidor SSL puede usar un certificado falso interno</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="337"/>
        <source>SSL CA Certificates</source>
        <translation>Certificados de CA SSL</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="344"/>
        <source>Path from where to load the CA certificats (leave empty for defaults)</source>
        <translation>Ruta desde donde cargar los certificados de CA (dejar en blanco para los valores predeterminados)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="351"/>
        <location filename="../settings.ui" line="376"/>
        <location filename="../settings.ui" line="401"/>
        <source>Browse</source>
        <translation>Navegar</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="362"/>
        <source>SSL Local Certificate</source>
        <translation>Certificado Local SSL</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="369"/>
        <source>File path for the client side local certificate</source>
        <translation>Ruta de archivo para el certificado local del lado del cliente</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="387"/>
        <source>SSL Private Key</source>
        <translation>Clave Privada SSL</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="394"/>
        <source>File path for the client side private key</source>
        <translation>Ruta de Archivo para la clave privada del lado del cliente</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="430"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="436"/>
        <source>Automatically adjust ContentType when sending XML or JSON</source>
        <translation>Ajustar automáticamente el Tipo de Contenido al enviar XML o JSON</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="458"/>
        <source>Generate Auth Header</source>
        <translation>Generar Encabezado de Autenticación</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="469"/>
        <location filename="../settings.cpp" line="975"/>
        <source>Host</source>
        <translation>Anfitrión</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="479"/>
        <source>Username/ClientID</source>
        <translation>Nombre de Usuario/ID de Cliente</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="489"/>
        <source>Password/AccessCode</source>
        <translation>Contraseña/Código de Acceso</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="499"/>
        <location filename="../settings.cpp" line="1046"/>
        <source>HTTP Header</source>
        <translation>Encabezado HTTP</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="530"/>
        <source>Delete Header</source>
        <translation>Eliminar Encabezado</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="540"/>
        <source>Display</source>
        <translation>Mostrar</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="548"/>
        <source>Saved Packet Display Order (Drag and Drop)</source>
        <translation>Orden de Visualización de Paquetes Guardados (arrastrar y soltar)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="555"/>
        <location filename="../settings.ui" line="583"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="560"/>
        <location filename="../settings.ui" line="588"/>
        <source>To IP</source>
        <translation>IP Final</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="565"/>
        <location filename="../settings.ui" line="593"/>
        <source>From IP</source>
        <translation>IP Inicial</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="576"/>
        <source>Traffic Log Display Order (Drag and Drop)</source>
        <translation>Orden de Visualización del Registro de Tráfico (arrastrar y soltar)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="601"/>
        <source>Use Default Order</source>
        <translation>Usar Orden Predeterminado</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="626"/>
        <source>Miscellaneous</source>
        <translation>Misceláneos</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="632"/>
        <source>Use Dark Theme (requires restart)</source>
        <translation>Usar tema oscuro (Es necesario reiniciar)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="641"/>
        <source>Language (Requires Restart)</source>
        <translation>Idioma (Es necesario reiniciar)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="650"/>
        <source>Copy to Clipboard button uses raw data</source>
        <translation>El botón Copiar al portapapeles usa datos sin procesar</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="657"/>
        <source>Rolling 100-entry traffic log</source>
        <translation>Registro de Tráfico Continuo de 100 entradas</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="664"/>
        <source>Restore previous session</source>
        <translation>Restablecer sesión previa</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="671"/>
        <source>Periodically check for updates</source>
        <translation>Comprobar periódicamente si hay actualizaciones</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="678"/>
        <source>Use ellipsis [...] for long data entries (helps performance)</source>
        <translation>usar puntos suspensivos [...] para entradas de datos largas (ayuda al rendimiento)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="685"/>
        <source>Auto-Launch Starter Panel</source>
        <translation>Ejecutar Automáticamente el Panel Inicial</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="722"/>
        <source>Smart Responses</source>
        <translation>Respuestas Inteligentes</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="730"/>
        <source>Send a Smart Response with Macro Support</source>
        <translation>Enviar una respuesta inteligente con compatibilidad con Macros</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="758"/>
        <source>Response 5</source>
        <translation>Respuesta 5</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="766"/>
        <location filename="../settings.ui" line="828"/>
        <location filename="../settings.ui" line="862"/>
        <location filename="../settings.ui" line="903"/>
        <location filename="../settings.ui" line="936"/>
        <source>Mixed ASCII</source>
        <translation>ASCII mixto</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="779"/>
        <location filename="../settings.ui" line="844"/>
        <location filename="../settings.ui" line="882"/>
        <location filename="../settings.ui" line="895"/>
        <location filename="../settings.ui" line="928"/>
        <source>Enable</source>
        <translation>Habilitar</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="786"/>
        <source>Response 4</source>
        <translation>Respuesta 4</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="793"/>
        <source>If Packet data equals</source>
        <translation>Si los datos del paquete son iguales</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="800"/>
        <source>Reply with</source>
        <translation>Responder con</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="807"/>
        <source>Encoding</source>
        <translation>Codificación</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="814"/>
        <source>Response 1</source>
        <translation>Respuesta 1</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="854"/>
        <source>Response 2</source>
        <translation>Respuesta 2</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="875"/>
        <source>Response 3</source>
        <translation>Respuesta 3</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="963"/>
        <source>Available macros: {{DATE}} {{TIME}} {{RANDOM}} {{UNIXTIME}} {{UNIQUE}}</source>
        <translation>Macros disponibles: {{DATE}} {{TIME}} {{RANDOM}} {{UNIXTIME}} {{UNIQUE}}</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="970"/>
        <source>Packet Sender will swap macro with a real value before sending</source>
        <translation>Packet Sender intercambiará ek macro con un valor real antes de enviar</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="981"/>
        <source>{{DATE}} format (Requires Restart)</source>
        <translation>{{DATE}} formato (Es necesario reiniciar)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="998"/>
        <location filename="../settings.ui" line="1039"/>
        <source>Example</source>
        <translation>Ejemplo</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="1022"/>
        <source>{{TIME}} format (Requires Restart)</source>
        <translation>{{TIME}} formato (Es necesario reiniciar)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="1083"/>
        <source>Online Documentation</source>
        <translation>Documentación en línea</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="103"/>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="359"/>
        <source>Bad IP.</source>
        <translation>IP Inválida</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="363"/>
        <source>Packet Sender cannot bind invalid IP </source>
        <translation>Packet Sender no puede vincularse a una IP Inválida</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="377"/>
        <source>TCP and SSL non-zero port conflict.</source>
        <translation>Conflicto de puertos TCP y SSL distinto de cero.</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="381"/>
        <source>Packet Sender cannot bind TCP and SSL to the same port.</source>
        <translation>Packet Sender no puede vincular TCP y SSL al mismo puerto.</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="726"/>
        <source>Open Directory</source>
        <translation>Abrir Directorio</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="747"/>
        <source>Choose Cert</source>
        <translation>Seleccionar Certificado</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="747"/>
        <source>Certs (*.pem)</source>
        <translation>Certificados (*.pem)</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="763"/>
        <source>Choose Key</source>
        <translation>Elegir clave</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="763"/>
        <source>Keys (*.key, *.pem)</source>
        <translation>Claves (*.key, *.pem)</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="975"/>
        <location filename="../settings.cpp" line="1044"/>
        <source>Key</source>
        <translation>Clave</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="975"/>
        <location filename="../settings.cpp" line="1045"/>
        <source>Value</source>
        <translation>Valor</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="1040"/>
        <source>UN/ClientID</source>
        <translation>Nombre de usuario/ID de cliente</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="1041"/>
        <source>PW/Access</source>
        <translation>Contraseña/Código de acceso</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="1042"/>
        <source>HTTP Auth Header</source>
        <translation>HTTP encabezado de autenticación</translation>
    </message>
</context>
<context>
    <name>SubnetCalc</name>
    <message>
        <location filename="../subnetcalc.ui" line="14"/>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="26"/>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="33"/>
        <source>IPv4 address</source>
        <translation>Dirección IPv4</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="44"/>
        <source>Subnet</source>
        <translation>subred</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="51"/>
        <source>Dotted or number of bits </source>
        <translation> Punteado o número de bits </translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="66"/>
        <source>Start</source>
        <translation>Comenzar</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="76"/>
        <source>Calculated Start..</source>
        <translation>Inicio Calculado..</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="87"/>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="97"/>
        <source>Calculated End...</source>
        <translation>Fin calculado...</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="108"/>
        <source>Broadcast</source>
        <translation>Transmisión</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="118"/>
        <source>Broadcast...</source>
        <translation>Transmisión...</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="133"/>
        <source>Within subnet check</source>
        <translation>Dentro de la verificación de subred</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="140"/>
        <source>IP Address...</source>
        <translation>Dirección IP...</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="156"/>
        <source>Subnet Check Result...</source>
        <translation>Resultado de comprobación de subred...</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="168"/>
        <source>Results log...</source>
        <translation>Registro de Resultados...</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="177"/>
        <source>Clear</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <location filename="../subnetcalc.cpp" line="24"/>
        <source>IPv4 Subnet Calculator</source>
        <translation>Calculador de Subred IPv4</translation>
    </message>
    <message>
        <location filename="../subnetcalc.cpp" line="26"/>
        <source>Your non-loopback addresses: 

</source>
        <translation>Sus direcciones no loopback:

</translation>
    </message>
    <message>
        <location filename="../subnetcalc.cpp" line="263"/>
        <source>Within </source>
        <translation>Dentro de </translation>
    </message>
    <message>
        <location filename="../subnetcalc.cpp" line="273"/>
        <source>No entries in subnet.</source>
        <translation>No hay entradas en la subred.</translation>
    </message>
</context>
<context>
    <name>UDPFlooding</name>
    <message>
        <location filename="../udpflooding.ui" line="14"/>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="24"/>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="38"/>
        <source>Port</source>
        <translation>Puerto</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="54"/>
        <source>Ascii</source>
        <translation>Ascii</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="76"/>
        <source>Delay (ms)</source>
        <translation>Retardo (ms)</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="86"/>
        <source>Speed (MB/s)</source>
        <translation>Velocidad (MB/s)</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="101"/>
        <source>0 or blank is no delay or max speed</source>
        <translation>0 o en blanco no significa retraso ni velocidad máxima</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="110"/>
        <source>Start</source>
        <translation>Comenzar</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="117"/>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="139"/>
        <source>Waiting to send...</source>
        <translation>Esperando para enviar...</translation>
    </message>
    <message>
        <location filename="../udpflooding.cpp" line="25"/>
        <source>UDP Traffic Generator (Experimental)</source>
        <translation>Generador de Tráfico UDP (Experimental)</translation>
    </message>
    <message>
        <location filename="../udpflooding.cpp" line="76"/>
        <location filename="../udpflooding.cpp" line="81"/>
        <source>Invalid</source>
        <translation>Inválido</translation>
    </message>
</context>
</TS>
